pub enum QuerySource {
ById(Uuid),
ByLogQl(LogQlQuery),
}Expand description
Specifies the source of records for a query, either by a direct ID or a LogQL query.
Variants
ById(Uuid)
Specifies a single log group by its unique identifier.
ByLogQl(LogQlQuery)
Specifies records to be fetched using a full LogQL query.