pub struct LogQlQuery {
pub selector: StreamSelector,
pub filter: Option<LineFilter>,
}Expand description
Represents a LogQL query, combining a stream selector and an optional line filter.
Fields
selector: StreamSelectorThe mechanism for selecting log streams (e.g., by group IDs).
filter: Option<LineFilter>An optional filter to apply to the content of log lines.