pub struct GrokSet { /* private fields */ }Expand description
A convenience wrapper over regex::RegexSet::matches and Grokker variants.
GrokSet provides methods to check if a string matches certain predefined
data patterns (groks).
Implementations
Sourceimpl GrokSet
impl GrokSet
Sourcepub fn is_numeric(&self) -> bool
pub fn is_numeric(&self) -> bool
Checks if any of the matched Grokker types are numeric (integers or floats).
Returns
true if the GrokSet contains any numeric Grokker type, false otherwise.
Sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Checks if any of the matched Grokker types are integers (base-10 or base-16).
Returns
true if the GrokSet contains any integer Grokker type, false otherwise.